@@ -1,7 +1,7 @@
 /*
  * Automated Testing Framework (atf)
  *
- * Copyright (c) 2008 The NetBSD Foundation, Inc.
+ * Copyright (c) 2008, 2009 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@
 
 #include "atf-c/dynstr.h"
 #include "atf-c/error.h"
+#include "atf-c/sanity.h"
 #include "atf-c/text.h"
 
 atf_error_t
@@ -91,6 +92,53 @@ atf_text_format_ap(char **dest, const char *fmt, va_list ap)
     return err;
 }
 
+atf_error_t
+atf_text_split(const char *str, const char *delim, atf_list_t *words)
+{
+    atf_error_t err;
+    const char *end;
+    const char *iter;
+
+    err = atf_list_init(words);
+    if (atf_is_error(err))
+        goto err;
+
+    end = str + strlen(str);
+    INV(*end == '\0');
+    iter = str;
+    while (iter < end) {
+        const char *ptr;
+
+        INV(iter != NULL);
+        ptr = strstr(iter, delim);
+        if (ptr == NULL)
+            ptr = end;
+
+        INV(ptr >= iter);
+        if (ptr > iter) {
+            atf_dynstr_t word;
+
+            err = atf_dynstr_init_raw(&word, iter, ptr - iter);
+            if (atf_is_error(err))
+                goto err_list;
+
+            err = atf_list_append(words, atf_dynstr_fini_disown(&word), true);
+            if (atf_is_error(err))
+                goto err_list;
+        }
+
+        iter = ptr + strlen(delim);
+    }
+
+    INV(!atf_is_error(err));
+    return err;
+
+err_list:
+    atf_list_fini(words);
+err:
+    return err;
+}
+
 atf_error_t
 atf_text_to_bool(const char *str, bool *b)
 {
