@@ -41,7 +41,6 @@
 #include "atf-c/dynstr.h"
 #include "atf-c/error.h"
 #include "atf-c/fs.h"
-#include "atf-c/object.h"
 #include "atf-c/map.h"
 #include "atf-c/sanity.h"
 #include "atf-c/tc.h"
@@ -180,7 +179,7 @@ print_error(const atf_error_t err)
 struct params {
     bool m_do_list;
     bool m_do_usage;
-    const char *m_srcdir;
+    atf_fs_path_t m_srcdir;
     char *m_tcname;
     enum tc_part m_tcpart;
     atf_fs_path_t m_resfile;
@@ -189,23 +188,47 @@ struct params {
 
 static
 atf_error_t
-params_init(struct params *p)
+argv0_to_dir(const char *argv0, atf_fs_path_t *dir)
+{
+    atf_error_t err;
+    atf_fs_path_t temp;
+
+    err = atf_fs_path_init_fmt(&temp, "%s", argv0);
+    if (atf_is_error(err))
+        goto out;
+
+    err = atf_fs_path_branch_path(&temp, dir);
+
+    atf_fs_path_fini(&temp);
+out:
+    return err;
+}
+
+static
+atf_error_t
+params_init(struct params *p, const char *argv0)
 {
     atf_error_t err;
 
     p->m_do_list = false;
     p->m_do_usage = false;
-    p->m_srcdir = ".";
     p->m_tcname = NULL;
     p->m_tcpart = BODY;
 
-    err = atf_fs_path_init_fmt(&p->m_resfile, "resfile"); /* XXX Bad default */
+    err = argv0_to_dir(argv0, &p->m_srcdir);
     if (atf_is_error(err))
         return err;
 
+    err = atf_fs_path_init_fmt(&p->m_resfile, "resfile"); /* XXX Bad default */
+    if (atf_is_error(err)) {
+        atf_fs_path_fini(&p->m_srcdir);
+        return err;
+    }
+
     err = atf_map_init(&p->m_config);
     if (atf_is_error(err)) {
         atf_fs_path_fini(&p->m_resfile);
+        atf_fs_path_fini(&p->m_srcdir);
         return err;
     }
 
@@ -218,6 +241,7 @@ params_fini(struct params *p)
 {
     atf_map_fini(&p->m_config);
     atf_fs_path_fini(&p->m_resfile);
+    atf_fs_path_fini(&p->m_srcdir);
     if (p->m_tcname != NULL)
         free(p->m_tcname);
 }
@@ -244,6 +268,22 @@ out:
     return err;
 }
 
+static
+atf_error_t
+replace_path_param(atf_fs_path_t *param, const char *value)
+{
+    atf_error_t err;
+    atf_fs_path_t temp;
+
+    err = atf_fs_path_init_fmt(&temp, "%s", value);
+    if (!atf_is_error(err)) {
+        atf_fs_path_fini(param);
+        *param = temp;
+    }
+
+    return err;
+}
+
 /* ---------------------------------------------------------------------
  * Test case listing.
  * --------------------------------------------------------------------- */
@@ -353,7 +393,7 @@ process_params(int argc, char **argv, struct params *p)
     atf_error_t err;
     int ch;
 
-    err = params_init(p);
+    err = params_init(p, argv[0]);
     if (atf_is_error(err))
         goto out;
 
@@ -370,18 +410,11 @@ process_params(int argc, char **argv, struct params *p)
             break;
 
         case 'r':
-            {
-                atf_fs_path_t resfile;
-                err = atf_fs_path_init_fmt(&resfile, "%s", optarg);
-                if (!atf_is_error(err)) {
-                    atf_fs_path_fini(&p->m_resfile);
-                    p->m_resfile = resfile;
-                }
-            }
+            err = replace_path_param(&p->m_resfile, optarg);
             break;
 
         case 's':
-            p->m_srcdir = optarg;
+            err = replace_path_param(&p->m_srcdir, optarg);
             break;
 
         case 'v':
@@ -426,15 +459,35 @@ out:
     return err;
 }
 
+static
+atf_error_t
+srcdir_strip_libtool(atf_fs_path_t *srcdir)
+{
+    atf_error_t err;
+    atf_fs_path_t parent;
+
+    err = atf_fs_path_branch_path(srcdir, &parent);
+    if (atf_is_error(err))
+        goto out;
+
+    atf_fs_path_fini(srcdir);
+    *srcdir = parent;
+
+    INV(!atf_is_error(err));
+out:
+    return err;
+}
+
 static
 atf_error_t
 handle_srcdir(struct params *p)
 {
     atf_error_t err;
+    atf_dynstr_t leafname;
     atf_fs_path_t exe, srcdir;
     bool b;
 
-    err = atf_fs_path_init_fmt(&srcdir, "%s", p->m_srcdir);
+    err = atf_fs_path_copy(&srcdir, &p->m_srcdir);
     if (atf_is_error(err))
         goto out;
 
@@ -449,6 +502,20 @@ handle_srcdir(struct params *p)
         srcdir = srcdirabs;
     }
 
+    err = atf_fs_path_leaf_name(&srcdir, &leafname);
+    if (atf_is_error(err))
+        goto out_srcdir;
+    else {
+        const bool libs = atf_equal_dynstr_cstring(&leafname, ".libs");
+        atf_dynstr_fini(&leafname);
+
+        if (libs) {
+            err = srcdir_strip_libtool(&srcdir);
+            if (atf_is_error(err))
+                goto out;
+        }
+    }
+
     err = atf_fs_path_copy(&exe, &srcdir);
     if (atf_is_error(err))
         goto out_srcdir;
@@ -464,7 +531,7 @@ handle_srcdir(struct params *p)
                                  strdup(atf_fs_path_cstring(&srcdir)), true);
         } else {
             err = user_error("Cannot find the test program in the source "
-                             "directory `%s'", p->m_srcdir);
+                             "directory `%s'", atf_fs_path_cstring(&srcdir));
         }
     }
 
@@ -577,14 +644,18 @@ atf_tp_main(int argc, char **argv, atf_error_t (*add_tcs_hook)(atf_tp_t *))
     atf_error_t err;
     int exitcode;
 
-    atf_init_objects();
-
     progname = strrchr(argv[0], '/');
     if (progname == NULL)
         progname = argv[0];
     else
         progname++;
 
+    /* Libtool workaround: if running from within the source tree (binaries
+     * that are not installed yet), skip the "lt-" prefix added to files in
+     * the ".libs" directory to show the real (not temporary) name. */
+    if (strncmp(progname, "lt-", 3) == 0)
+        progname += 3;
+
     exitcode = EXIT_FAILURE; /* Silence GCC warning. */
     err = controlled_main(argc, argv, add_tcs_hook, &exitcode);
     if (atf_is_error(err)) {
