@@ -67,6 +67,9 @@ class metadata_reader : public atf::formats::atf_tp_reader {
 
         if (m_tcs[ident].find("timeout") == m_tcs[ident].end())
             m_tcs[ident].insert(std::make_pair("timeout", "300"));
+
+        if (m_tcs[ident].find("use.fs") == m_tcs[ident].end())
+            m_tcs[ident].insert(std::make_pair("use.fs", "false"));
     }
 
 public:
