@@ -1,7 +1,7 @@
 //
 // Automated Testing Framework (atf)
 //
-// Copyright (c) 2007, 2008, 2009 The NetBSD Foundation, Inc.
+// Copyright (c) 2007, 2008, 2009, 2010 The NetBSD Foundation, Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,6 @@
 
 extern "C" {
 #include <fcntl.h>
-#include <regex.h>
 #include <unistd.h>
 }
 
@@ -84,72 +83,10 @@ do_exec(const atf::tests::tc* tc, const char* helper_name, const char *carg2)
     return atf::check::exec(argva);
 }
 
-static
-bool
-grep_string(const std::string& str, const char* regex)
-{
-    int res;
-    regex_t preg;
-
-    std::cout << "Looking for '" << regex << "' in '" << str << "'\n";
-    ATF_CHECK(::regcomp(&preg, regex, REG_EXTENDED) == 0);
-
-    res = ::regexec(&preg, str.c_str(), 0, NULL, 0);
-    ATF_CHECK(res == 0 || res == REG_NOMATCH);
-
-    ::regfree(&preg);
-
-    return res == 0;
-}
-
-static
-bool
-grep_file(const char* name, const char* regex)
-{
-    std::ifstream is(name);
-    ATF_CHECK(is);
-
-    bool found = false;
-
-    std::string line;
-    std::getline(is, line);
-    while (!found && is.good()) {
-        if (grep_string(line, regex))
-            found = true;
-        else
-            std::getline(is, line);
-    }
-
-    return found;
-}
-
 // ------------------------------------------------------------------------
 // Helper test cases for the free functions.
 // ------------------------------------------------------------------------
 
-static
-void
-run_h_tc(atf::tests::tc& tc, const char* outname, const char* errname)
-{
-    const int fdout = ::open(outname, O_CREAT | O_WRONLY | O_TRUNC, 0600);
-    ATF_CHECK(fdout != -1);
-
-    const int fderr = ::open(errname, O_CREAT | O_WRONLY | O_TRUNC, 0600);
-    ATF_CHECK(fderr != -1);
-
-    atf::tests::vars_map config;
-    config["callerdir"] = atf::fs::get_current_dir().str();
-
-    tc.init(config);
-    const atf::tests::tcr tcr =
-        tc.run(fdout, fderr, atf::fs::get_current_dir());
-
-    ATF_CHECK_EQUAL(tcr.get_state(), atf::tests::tcr::passed_state);
-
-    ::close(fderr);
-    ::close(fdout);
-}
-
 ATF_TEST_CASE(h_build_c_o_ok);
 ATF_TEST_CASE_HEAD(h_build_c_o_ok)
 {
@@ -195,10 +132,8 @@ ATF_TEST_CASE_BODY(h_build_cpp_ok)
     sfile << "A B\n";
     sfile.close();
 
-    const atf::fs::path testp =
-        atf::fs::path(get_config_var("callerdir")) / "test.p";
-
-    ATF_CHECK(atf::check::build_cpp(atf::fs::path("test.c"), testp,
+    ATF_CHECK(atf::check::build_cpp(atf::fs::path("test.c"),
+                                    atf::fs::path("test.p"),
                                     atf::process::argv_array()));
 }
 
@@ -261,13 +196,11 @@ ATF_TEST_CASE_HEAD(build_c_o)
 }
 ATF_TEST_CASE_BODY(build_c_o)
 {
-    ATF_TEST_CASE_NAME(h_build_c_o_ok) h_build_c_o_ok;
-    run_h_tc(h_build_c_o_ok, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_c_o_ok) >();
     ATF_CHECK(grep_file("stdout", "-o test.o"));
     ATF_CHECK(grep_file("stdout", "-c test.c"));
 
-    ATF_TEST_CASE_NAME(h_build_c_o_fail) h_build_c_o_fail;
-    run_h_tc(h_build_c_o_fail, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_c_o_fail) >();
     ATF_CHECK(grep_file("stdout", "-o test.o"));
     ATF_CHECK(grep_file("stdout", "-c test.c"));
     ATF_CHECK(grep_file("stderr", "test.c"));
@@ -281,14 +214,12 @@ ATF_TEST_CASE_HEAD(build_cpp)
 }
 ATF_TEST_CASE_BODY(build_cpp)
 {
-    ATF_TEST_CASE_NAME(h_build_cpp_ok) h_build_cpp_ok;
-    run_h_tc(h_build_cpp_ok, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_cpp_ok) >();
     ATF_CHECK(grep_file("stdout", "-o.*test.p"));
     ATF_CHECK(grep_file("stdout", "test.c"));
     ATF_CHECK(grep_file("test.p", "foo bar"));
 
-    ATF_TEST_CASE_NAME(h_build_cpp_fail) h_build_cpp_fail;
-    run_h_tc(h_build_cpp_fail, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_cpp_fail) >();
     ATF_CHECK(grep_file("stdout", "-o test.p"));
     ATF_CHECK(grep_file("stdout", "test.c"));
     ATF_CHECK(grep_file("stderr", "test.c"));
@@ -302,13 +233,11 @@ ATF_TEST_CASE_HEAD(build_cxx_o)
 }
 ATF_TEST_CASE_BODY(build_cxx_o)
 {
-    ATF_TEST_CASE_NAME(h_build_cxx_o_ok) h_build_cxx_o_ok;
-    run_h_tc(h_build_cxx_o_ok, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_cxx_o_ok) >();
     ATF_CHECK(grep_file("stdout", "-o test.o"));
     ATF_CHECK(grep_file("stdout", "-c test.cpp"));
 
-    ATF_TEST_CASE_NAME(h_build_cxx_o_fail) h_build_cxx_o_fail;
-    run_h_tc(h_build_cxx_o_fail, "stdout", "stderr");
+    run_h_tc< ATF_TEST_CASE_NAME(h_build_cxx_o_fail) >();
     ATF_CHECK(grep_file("stdout", "-o test.o"));
     ATF_CHECK(grep_file("stdout", "-c test.cpp"));
     ATF_CHECK(grep_file("stderr", "test.cpp"));
@@ -417,15 +346,20 @@ ATF_TEST_CASE_BODY(exec_stdout_stderr)
     const atf::fs::path& err1 = r1.stderr_path();
     const atf::fs::path& err2 = r2.stderr_path();
 
-    ATF_CHECK(out1.str().find("stdout.XXXXXX") == std::string::npos);
-    ATF_CHECK(out2.str().find("stdout.XXXXXX") == std::string::npos);
-    ATF_CHECK(err1.str().find("stderr.XXXXXX") == std::string::npos);
-    ATF_CHECK(err2.str().find("stderr.XXXXXX") == std::string::npos);
+    ATF_CHECK(out1.str().find("check.XXXXXX") == std::string::npos);
+    ATF_CHECK(out2.str().find("check.XXXXXX") == std::string::npos);
+    ATF_CHECK(err1.str().find("check.XXXXXX") == std::string::npos);
+    ATF_CHECK(err2.str().find("check.XXXXXX") == std::string::npos);
 
-    ATF_CHECK(out1.str().find("stdout.") != std::string::npos);
-    ATF_CHECK(out2.str().find("stdout.") != std::string::npos);
-    ATF_CHECK(err1.str().find("stderr.") != std::string::npos);
-    ATF_CHECK(err2.str().find("stderr.") != std::string::npos);
+    ATF_CHECK(out1.str().find("/check") != std::string::npos);
+    ATF_CHECK(out2.str().find("/check") != std::string::npos);
+    ATF_CHECK(err1.str().find("/check") != std::string::npos);
+    ATF_CHECK(err2.str().find("/check") != std::string::npos);
+
+    ATF_CHECK(out1.str().find("/stdout") != std::string::npos);
+    ATF_CHECK(out2.str().find("/stdout") != std::string::npos);
+    ATF_CHECK(err1.str().find("/stderr") != std::string::npos);
+    ATF_CHECK(err2.str().find("/stderr") != std::string::npos);
 
     ATF_CHECK(out1 != out2);
     ATF_CHECK(err1 != err2);
