@@ -1,7 +1,7 @@
 /*
  * Automated Testing Framework (atf)
  *
- * Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
+ * Copyright (c) 2007, 2008, 2009 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,8 @@
 
 #include "atf-c/user.h"
 
+#include "h_lib.h"
+
 /* ---------------------------------------------------------------------
  * Test cases for the free functions.
  * --------------------------------------------------------------------- */
@@ -125,6 +127,12 @@ ATF_TC_BODY(is_unprivileged, tc)
         ATF_REQUIRE(!atf_user_is_unprivileged());
 }
 
+/* ---------------------------------------------------------------------
+ * Tests cases for the header file.
+ * --------------------------------------------------------------------- */
+
+HEADER_TC(include, "atf-c/user.h", "d_include_user_h.c");
+
 /* ---------------------------------------------------------------------
  * Main.
  * --------------------------------------------------------------------- */
@@ -136,5 +144,8 @@ ATF_TP_ADD_TCS(tp)
     ATF_TP_ADD_TC(tp, is_root);
     ATF_TP_ADD_TC(tp, is_unprivileged);
 
+    /* Add the test cases for the header file. */
+    ATF_TP_ADD_TC(tp, include);
+
     return atf_no_error();
 }
